@@ -49,6 +49,7 @@
 #' @return An `auk_ebd` object with the output files set. If `execute = FALSE`,
 #'   then the path to the AWK script is returned instead.
 #' @export
+#' @family filter
 #' @examples
 #' # get the path to the example data included in the package
 #' # in practice, provide path to ebd, e.g. f <- "data/ebd_relFeb-2018.txt"
@@ -120,7 +121,7 @@ auk_filter.auk_ebd <- function(x, file, file_sampling, keep, drop, awk_file,
     if (!overwrite && file.exists(file) && execute) {
       stop("Output file already exists, use overwrite = TRUE.")
     }
-    file <- path.expand(file)
+    file <- normalizePath(file, mustWork = FALSE)
   }
   # check output awk file
   if (!missing(awk_file) && !dir.exists(dirname(awk_file))) {
@@ -140,7 +141,7 @@ auk_filter.auk_ebd <- function(x, file, file_sampling, keep, drop, awk_file,
     if (!overwrite && file.exists(file_sampling) && execute) {
       stop("Output sampling file already exists, use overwrite = TRUE.")
     }
-    file_sampling <- path.expand(file_sampling)
+    file_sampling <- normalizePath(file_sampling, mustWork = FALSE)
   }
   # zero-filling requires complete checklists
   if (filter_sampling && !x$filters$complete) {
@@ -216,15 +217,17 @@ auk_filter.auk_ebd <- function(x, file, file_sampling, keep, drop, awk_file,
   if (!missing(awk_file)) {
     writeLines(awk_script, awk_file)
     if (!execute) {
-      return(normalizePath(awk_file))
+      return(normalizePath(awk_file, mustWork = FALSE))
     }
   }
 
   # run awk
   # ebd
+  err <- tempfile()
   exit_code <- system2(awk_path,
                        args = paste0("'", awk_script, "' '", x$file, "'"),
-                       stdout = file)
+                       stdout = file, stderr = err)
+  unlink(err)
   if (exit_code != 0) {
     stop("Error running AWK command.")
   } else {
@@ -233,10 +236,12 @@ auk_filter.auk_ebd <- function(x, file, file_sampling, keep, drop, awk_file,
 
   # ebd sampling
   if (filter_sampling) {
+    err <- tempfile()
     exit_code <- system2(awk_path,
                          args = paste0("'", awk_script_sampling, "' '",
                                        x$file_sampling, "'"),
-                         stdout = file_sampling)
+                         stdout = file_sampling, stderr = err)
+    unlink(err)
     if (exit_code != 0) {
       stop("Error running AWK command.")
     } else {
@@ -278,7 +283,7 @@ auk_filter.auk_sampling <- function(x, file, keep, drop, awk_file,
     if (!overwrite && file.exists(file)) {
       stop("Output file already exists, use overwrite = TRUE.")
     }
-    file <- path.expand(file)
+    file <- normalizePath(file, mustWork = FALSE)
   }
   # check output awk file
   if (!missing(awk_file) && !dir.exists(dirname(awk_file))) {
@@ -329,9 +334,11 @@ auk_filter.auk_sampling <- function(x, file, keep, drop, awk_file,
   
   # run awk
   # ebd
+  err <- tempfile()
   exit_code <- system2(awk_path,
                        args = paste0("'", awk_script, "' '", x$file, "'"),
-                       stdout = file)
+                       stdout = file, stderr = err)
+  unlink(err)
   if (exit_code != 0) {
     stop("Error running AWK command.")
   } else {
